@@ -1,4 +1,4 @@
-from lzw_c import *
+#from lzw_c import *
 from lz77c import lz77_decompress
 
 def glue_seq(seq, last_separate = False):
@@ -13,7 +13,7 @@ def code_filling(huff_codes):
     codes = {}
     for seq, code in huff_codes.items():
         cd = int("1" + code, 2)
-        sequences[cd] = lzw_compress(str(seq))
+        sequences[cd] = seq#lzw_compress(str(seq))
         codes[seq] = code
     return sequences, codes
 
@@ -24,13 +24,15 @@ def huffman_decode(sequences, compressed):
         bit += b
         bit_int = int("1" + bit, 2)
         if bit_int in sequences:
-            yield lzw_decompress(sequences[bit_int])
+            yield str(sequences[bit_int])#lzw_decompress(sequences[bit_int])
             bit = ""
 
 def org_shaping(seq, bits):
     org = " ".join(huffman_decode(seq, bits)).split()
     org = [i.replace("__", " ") for i in org]
-    return [eval(i) for i in org]
+    if "None" in org:
+        org = [eval(i) for i in org]
+    return org
 
 def lz77_decode(triplets):
     triplets = list(zip(triplets[0], triplets[1], triplets[2]))
